Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3964)

Unified Diff: chrome/browser/win/jumplist.h

Issue 2965973002: Remove delay for the first JumpList top site sync in one session (Closed)
Patch Set: Created 3 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/win/jumplist.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/win/jumplist.h
diff --git a/chrome/browser/win/jumplist.h b/chrome/browser/win/jumplist.h
index 30df91991bfc0b51fa63cf55be9b39b04e693a6b..fdcf6f6590ef5813945bdce9c9a20ec30535c034 100644
--- a/chrome/browser/win/jumplist.h
+++ b/chrome/browser/win/jumplist.h
@@ -124,10 +124,9 @@ class JumpList : public sessions::TabRestoreServiceObserver,
// quiet period, thus avoiding update storms.
void InitializeTimerForUpdate();
- // Called on a timer after requests storms have subsided. Calls APIs
- // ProcessTopSitesNotification and ProcessTabRestoreNotification on
- // demand to do the actual work.
- void OnDelayTimer();
+ // Processes update notifications. Calls APIs ProcessTopSitesNotification and
+ // ProcessTabRestoreNotification on demand to do the actual work.
+ void ProcessNotifications();
// Processes notifications from TopSites service.
void ProcessTopSitesNotification();
@@ -282,6 +281,9 @@ class JumpList : public sessions::TabRestoreServiceObserver,
// A flag indicating if a session has at least one tab closed.
bool has_tab_closed_ = false;
+ // A flag indicating if a session has at least one top sites sync.
+ bool has_topsites_sync = false;
+
// Number of updates to skip to alleviate the machine when a previous update
// was too slow. Updates will be resumed when this reaches 0 again.
int updates_to_skip_ = 0;
« no previous file with comments | « no previous file | chrome/browser/win/jumplist.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698